Package 'xegaGpGene'

Title: Genetic Operations for Grammar-Based Genetic Programming
Description: An implementation of the representation-dependent gene level operations of grammar-based genetic programming with genes which are derivation trees of a context-free grammar: Initialization of a gene with a complete random derivation tree, decoding of a derivation tree. Crossover is implemented by exchanging subtrees. Depth-bounds for the minimal and the maximal depth of the roots of the subtrees exchanged by crossover can be set. Mutation is implemented by replacing a subtree by a random subtree. The depth of the random subtree and the insertion node are configurable. For details, see Geyer-Schulz (1997, ISBN:978-3-7908-0830-X).
Authors: Andreas Geyer-Schulz [aut, cre] (ORCID: <https://orcid.org/0009-0000-5237-3579>)
Maintainer: Andreas Geyer-Schulz <[email protected]>
License: MIT + file LICENSE
Version: 1.0.0.3
Built: 2026-05-13 08:48:00 UTC
Source: https://github.com/ageyerschulz/xegagpgene

Help Index